@@ -16,10 +16,9 @@ Usage::
     session_client: ComputeOptimizerClient = session.client("compute-optimizer")
     ```
 """
-from mypy_boto3_compute_optimizer.client import (
-    ComputeOptimizerClient as Client,
-    ComputeOptimizerClient,
-)
+from mypy_boto3_compute_optimizer.client import ComputeOptimizerClient
+
+Client = ComputeOptimizerClient
 
 
 __all__ = ("Client", "ComputeOptimizerClient")
